pub enum X213NetworkAddressType {
X121,
ISO_DCC,
F69,
E163,
E164,
ISO_6523_ICD,
IANA_ICP,
ITU_T_IND,
LOCAL,
URL,
}Expand description
X.213 NSAP network address type
Variants
X121
IDI based on ITU-T Recommendation X.121 address for use in X.25 Networks
Quoting ITU-T Recommendation X.213 (2001):
The IDI consists of an international public data network number of up to 14 digits allocated according to ITU-T Rec. X.121, commencing with the Data Network Identification Code. The full X.121 number identifies an authority responsible for allocating and assigning values of the DSP.
ISO_DCC
IDI based on International Organization for Standardization (ISO) Data Country Code (DCC)
Quoting / Paraphrasing ITU-T Recommendation X.213 (2001):
The IDI consists of a fixed length 3-digit numeric code allocated according to ISO 3166-1. The DSP is allocated and assigned by the ISO member body or sponsored organization to which the ISO DCC value has been assigned, or by an organization designated by the holder of the ISO DCC value to carry out this responsibility.
See: https://en.wikipedia.org/wiki/List_of_ISO_3166_country_codes
F69
IDI based on ITU-T Recommendation F.69 address for use in Telex
Quoting ITU-T Recommendation X.213 (2001):
The IDI consists of a telex number of up to 8 digits, allocated according to ITU-T Rec. F.69, commencing with a 2- or 3-digit destination code. The full telex number identifies an authority responsible for allocating and assigning values of the DSP.
A particular IDI for this network type is used to provide a namespace
for IP networking within NSAP addressing: 00728722. Its usage is
described in IETF RFC
E163
IDI based on ITU-T Rec. E.163 address for use in the PSTN
This is a phone number. This network type was deprecated at or before 2001 and you should use E.164 addressing instead.
E164
IDI based on ITU-T Rec. E.164 address for use in the ISDN
This is a phone number.
Quoting ITU-T Recommendation X.213 (2001):
The IDI consists of an international public telecommunication numbering plan number of up to 15 digits allocated according to ITU-T Rec. E.164, commencing with the E.164 international number country code. The full E.164 number identifies an authority responsible for allocating and assigning values of the DSP.
ISO_6523_ICD
IDI is an assigned ISO/IEC 6523-1 International Code Designator (ICD)
IANA_ICP
IPv4 or IPv6 address, depending on the IDI, which is assigned by IANA
For either version, the IP address is encoded in binary format, and padded with zeroes to be exactly 20 bytes in total, after the AFI and IDI (which identifies the version).
ITU_T_IND
International Network Designator (IND)
LOCAL
Locally-assigned DSP
URL
Special URL encoding defined (without a name) in ITU-T Rec. X.519.
See: https://www.itu.int/rec/T-REC-X.519, Section 11.4